@@ -1,6 +1,7 @@
 package Dist::Zilla::PluginBundle::Author::BBYRD;
 
-our $VERSION = '1.01'; # VERSION
+our $AUTHORITY = 'cpan:BBYRD'; # AUTHORITY
+our $VERSION = '1.02'; # VERSION
 # ABSTRACT: DZIL Author Bundle for BBYRD
 
 use sanity;
@@ -8,12 +9,13 @@ use Moose;
 
 with 'Dist::Zilla::Role::PluginBundle::Merged' => {
    mv_plugins => [ qw(
-      Git::GatherDir OurPkgVersion PodWeaver Test::ReportPrereqs Test::Compile Test::NoTabs
+      Git::GatherDir OurPkgVersion PodWeaver Test::ReportPrereqs @TestingMania
       PruneCruft @Prereqs CheckPrereqsIndexed MetaNoIndex CopyFilesFromBuild
       Git::CheckFor::CorrectBranch @Git TravisYML
    ) ],
 };
 with 'Dist::Zilla::Role::PluginBundle::PluginRemover';
+with 'Dist::Zilla::Role::BundleDeps';
 
 sub configure {
    my $self = shift;
@@ -25,6 +27,14 @@ sub configure {
       #
       qw( ReportPhase MakeMaker ),
 
+      # [Authority]
+      # authority = cpan:BBYRD
+      # locate_comment = 1
+      [Authority => {
+         authority      => 'cpan:BBYRD',
+         locate_comment => 1,
+      }],
+
       # [Git::NextVersion]
       # first_version = 0.90
       $self->config_short_merge('Git::NextVersion', { first_version => '0.90' }),
@@ -67,41 +77,44 @@ sub configure {
       #
       # [InstallGuide]
       # [ExecDir]
+      qw( InstallGuide ExecDir ),
+
       #
-      # ; t/* tests
-      # [Test::Compile]
+      # ; Many tests
+      # [@TestingMania]
+      # disable = Test::Perl::Critic
+      # disable = Test::EOL
+      # disable = Test::Kwalitee
+      # disable = Test::Pod::LinkCheck
+      # disable = MetaTests
+      # changelog = CHANGES
+      $self->config_short_merge('@TestingMania' => {
+         disable => [
+            (map { 'Test::'.$_ } qw( Perl::Critic EOL Kwalitee Pod::LinkCheck )),
+            qw( MetaTests ),
+         ],
+         changelog => 'CHANGES'
+      }),
+
       #
       # ; POD tests
-      # [PodCoverageTests]
-      # [PodSyntaxTests]
       # ;[Test::PodSpelling]  ; Win32 install problems
       #
       # ; Other xt/* tests
       # [RunExtraTests]
       # ;[MetaTests]  ; until Test::CPAN::Meta supports 2.0
-      qw( InstallGuide ExecDir Test::Compile PodCoverageTests PodSyntaxTests RunExtraTests ),
+      qw( RunExtraTests ),
 
       # [Test::EOL]
       # trailing_whitespace = 0
       $self->config_short_merge('Test::EOL', { trailing_whitespace => 0 }),
 
-      #
-      # [Test::CPAN::Changes]
-      $self->config_short_merge('Test::CPAN::Changes', { changelog => 'CHANGES' }),
-
-      # [Test::CPAN::Meta::JSON]
       # [Test::CheckDeps]
-      # [Test::Portability]
       # ;[Test::Pod::LinkCheck]  ; Both of these are borked...
       # ;[Test::Pod::No404s]     ; ...I really need to create my own
-      # [Test::Synopsis]
-      # [Test::MinimumVersion]
       # [Test::ReportPrereqs]
       # [Test::CheckManifest]
-      # [Test::DistManifest]
-      # [Test::Version]
-      # [Test::NoTabs]
-      (map { 'Test::'.$_ } qw(CPAN::Meta::JSON CheckDeps Portability Synopsis MinimumVersion ReportPrereqs CheckManifest DistManifest Version NoTabs)),
+      (map { 'Test::'.$_ } qw(CheckDeps ReportPrereqs CheckManifest)),
 
       #
       # ; Prereqs
@@ -156,11 +169,16 @@ sub configure {
       #
       # ; Post-build Git plugins
       # [TravisYML]
+      # notify_email = 0
       # notify_irc = irc://irc.perl.org/#sanity
+      # ; used for Travis::TestRelease
+      # support_builddir = 1
       # ; keep sanity from balking at these
       # post_before_install_build = cpanm --quiet --notest --skip-satisfied autovivification indirect multidimensional
       $self->config_short_merge('TravisYML', {
-         notify_irc => 'irc://irc.perl.org/#sanity',
+         notify_email     => 0,
+         notify_irc       => 'irc://irc.perl.org/#sanity',
+         support_builddir => 1,
          post_before_install_build => 'cpanm --quiet --notest --skip-satisfied autovivification indirect multidimensional',
       }),
 
@@ -169,6 +187,7 @@ sub configure {
       'Git::CheckFor::CorrectBranch',
 
       # [Git::CommitBuild]
+      # branch =
       # release_branch = build/%b
       # release_message = Release build of v%v (on %b)
       $self->config_short_merge('Git::CommitBuild', {
@@ -200,11 +219,20 @@ sub configure {
 
       #
       # [TestRelease]
+      'TestRelease',
+
+      # [Travis::TestRelease]
+      # create_builddir = 1
+      $self->config_short_merge('Travis::TestRelease', {
+         create_builddir => 1,
+         open_status_url => 1,
+      }),
+
       # [ConfirmRelease]
       # [UploadToCPAN]
       # [InstallRelease]
       # [Clean]
-      qw( TestRelease ConfirmRelease UploadToCPAN InstallRelease Clean ),
+      qw( ConfirmRelease UploadToCPAN InstallRelease Clean ),
    );
 }
 
@@ -229,6 +257,10 @@ Dist::Zilla::PluginBundle::Author::BBYRD - DZIL Author Bundle for BBYRD
     ; Makefile.PL maker
     [MakeMaker]
  
+    [Authority]
+    authority = cpan:BBYRD
+    locate_comment = 1
+ 
     [Git::NextVersion]
     first_version = 0.90
  
@@ -255,12 +287,16 @@ Dist::Zilla::PluginBundle::Author::BBYRD - DZIL Author Bundle for BBYRD
     [InstallGuide]
     [ExecDir]
  
-    ; t/* tests
-    [Test::Compile]
+    ; Many tests
+    [@TestingMania]
+    disable = Test::Perl::Critic
+    disable = Test::EOL
+    disable = Test::Kwalitee
+    disable = Test::Pod::LinkCheck
+    disable = MetaTests
+    changelog = CHANGES
  
     ; POD tests
-    [PodCoverageTests]
-    [PodSyntaxTests]
     ;[Test::PodSpelling]  ; Win32 install problems
  
     ; Other xt/* tests
@@ -269,18 +305,11 @@ Dist::Zilla::PluginBundle::Author::BBYRD - DZIL Author Bundle for BBYRD
     [Test::EOL]
     trailing_whitespace = 0
  
-    [Test::CPAN::Meta::JSON]
     [Test::CheckDeps]
-    [Test::Portability]
     ;[Test::Pod::LinkCheck]  ; Both of these are borked...
     ;[Test::Pod::No404s]     ; ...I really need to create my own
-    [Test::Synopsis]
-    [Test::MinimumVersion]
     [Test::ReportPrereqs]
     [Test::CheckManifest]
-    [Test::DistManifest]
-    [Test::Version]
-    [Test::NoTabs]
  
     ; Prereqs
     [@Prereqs]
@@ -315,7 +344,10 @@ Dist::Zilla::PluginBundle::Author::BBYRD - DZIL Author Bundle for BBYRD
  
     ; Post-build Git plugins
     [TravisYML]
+    notify_email = 0
     notify_irc = irc://irc.perl.org/#sanity
+    ; used for Travis::TestRelease
+    support_builddir = 1
     ; keep sanity from balking at these
     post_before_install_build = cpanm --quiet --notest --skip-satisfied autovivification indirect multidimensional
  
@@ -338,6 +370,9 @@ Dist::Zilla::PluginBundle::Author::BBYRD - DZIL Author Bundle for BBYRD
     metacpan = 1
  
     [TestRelease]
+    [Travis::TestRelease]
+    create_builddir = 1
+ 
     [ConfirmRelease]
     [UploadToCPAN]
     [InstallRelease]
